macro_rules! check_msg {
($id: ident, $typ: ty, $m: expr_2021, $got: pat, $x: ident) => { ... };
}Expand description
Generates a test which serializes and deserializes a message and verifies the message is unchanged.
macro_rules! check_msg {
($id: ident, $typ: ty, $m: expr_2021, $got: pat, $x: ident) => { ... };
}Generates a test which serializes and deserializes a message and verifies the message is unchanged.